@@ -125,7 +125,7 @@ void g_mozilla_connectivity_handle (GMozillaEngine *self, gint event)
             if (self->waiting_connection && self->will_open_location) {
                 g_mozilla_connectivity_set_proxy();
                 ULOG_INFO_F("Engine: %p: LoadUrl: '%s'\n", self->engine, self->will_open_location);
-                // self->waiting_connection = FALSE;
+                self->waiting_connection = FALSE;
                 if (!g_str_has_prefix(self->will_open_location, "file://"))
                     gtk_moz_embed_load_url(GTK_MOZ_EMBED(self->engine), self->will_open_location);
             } else if (self->progress_bar_state == 0 && !self->is_loading) {
